package entity

// QueryParsedJSON is used for JSON conversion of the incoming byte array
type QueryParsedJSON struct {
	DatabaseName string
	Return       QueryReturnStruct
	Entities     []QueryEntityStruct
	Relations    []QueryRelationStruct

	// Limit is for limiting the amount of paths AQL will return in a relation let statement
	Limit int
}

// QueryReturnStruct holds the indices of the entities and relations that need to be returned
type QueryReturnStruct struct {
	Entities  []int
	Relations []int
}

// QueryEntityStruct encapsulates a single entity with its corresponding constraints
type QueryEntityStruct struct {
	Type        string
	Constraints []QueryConstraintStruct
}

// QueryRelationStruct encapsulates a single relation with its corresponding constraints
type QueryRelationStruct struct {
	Type        string
	EntityFrom  int
	EntityTo    int
	Depth       QuerySearchDepthStruct
	Constraints []QueryConstraintStruct
}

// QuerySearchDepthStruct holds the range of traversals for the relation
type QuerySearchDepthStruct struct {
	Min int
	Max int
}

/*
QueryConstraintStruct holds the information of the constraint

Constraint datatypes
	text     MatchTypes: exact/contains/startswith/endswith
	number   MatchTypes: GT/LT/EQ
	bool     MatchTypes: EQ/NEQ
*/
type QueryConstraintStruct struct {
	Attribute string
	Value     string
	DataType  string
	MatchType string
}
